Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ExecuteRun ¶
func ExecuteRun(ctx context.Context, drv driver.Connection, sql string, limitFlag int, write bool, expand string, full bool, compact bool, formatFlag string) error
ExecuteRun runs a SQL query on an already-resolved connection and writes results. Uses streaming (QueryStream) when the driver supports it, falling back to buffered Query.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.