Documentation
¶
Overview ¶
Package snowflake implements the Snowflake driver using the SQL REST API v2. Uses net/http (no external dependencies) with PAT (Personal Access Token) auth.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ClassifyError ¶
ClassifyError classifies a Snowflake error. Exported for testing.
func Connect ¶
func Connect(opts Opts) (driver.Connection, error)
Connect creates a new Snowflake connection via the SQL REST API v2.
func ParseValue ¶
ParseValue converts a raw Snowflake string value to the appropriate Go type. Exported for testing.
func ValidateReadOnly ¶
ValidateReadOnly checks if a SQL statement is allowed in read-only mode. Exported for testing.
Types ¶
Click to show internal directories.
Click to hide internal directories.